@@ -56,7 +56,7 @@ class Typologie(EnhancedEnum):
     CAARUD = (
         "CAARUD",
         (
-            "CAARUD - Centre d'accueil et d'accompagnement à la réduction de risques "
+            "CAARUD - Centre d’accueil et d’accompagnement à la réduction de risques "
             "pour usagers de drogues"
         ),
         None,
@@ -138,7 +138,7 @@ class Typologie(EnhancedEnum):
     )
     CSAPA = (
         "CSAPA",
-        "CSAPA - Centre de soins, d'accompagnement et de prévention en addictologie",
+        "CSAPA - Centre de soins, d’accompagnement et de prévention en addictologie",
         None,
     )
     DEETS = (
@@ -191,12 +191,12 @@ class Typologie(EnhancedEnum):
     )
     EPIDE = (
         "EPIDE",
-        "EPIDE - Établissement pour l'insertion dans l'emploi",
+        "EPIDE - Établissement pour l’insertion dans l’emploi",
         None,
     )
     ESS = (
         "ESS",
-        "Entreprise de l'Économie Sociale et Solidaire",
+        "Entreprise de l’Économie Sociale et Solidaire",
         None,
     )
     ETTI = (
@@ -216,17 +216,17 @@ class Typologie(EnhancedEnum):
     )
     HUDA = (
         "HUDA",
-        "HUDA - Hébergement d'urgence pour demandeurs d'asile",
+        "HUDA - Hébergement d’urgence pour demandeurs d’asile",
         None,
     )
     MDE = (
         "MDE",
-        "Maison de l'emploi",
+        "Maison de l’emploi",
         None,
     )
     MDEF = (
         "MDEF",
-        "Maison de l'emploi et de la formation",
+        "Maison de l’emploi et de la formation",
         None,
     )
     MDPH = (
@@ -274,7 +274,7 @@ class Typologie(EnhancedEnum):
     )
     ODC = (
         "ODC",
-        "Organisation délégataire d'un CD",
+        "Organisation délégataire d’un CD",
         None,
     )
     OF = (
@@ -284,7 +284,7 @@ class Typologie(EnhancedEnum):
     )
     OIL = (
         "OIL",
-        "Opérateur d'intermédiation locative",
+        "Opérateur d’intermédiation locative",
         None,
     )
     OPCS = (
@@ -294,7 +294,7 @@ class Typologie(EnhancedEnum):
     )
     PAD = (
         "PAD",
-        "Point d'Accès au Droit",
+        "Point d’Accès au Droit",
         None,
     )
     PE = (
@@ -422,12 +422,12 @@ class LabelNational(EnhancedEnum):
     )
     APELS = (
         "apels",
-        "APELS Agence Pour l'Education par Le Sport",
+        "APELS Agence Pour l’Education par Le Sport",
         None,
     )
     APPRENTIS_DAUTEUIL = (
         "apprentis-dauteuil",
-        "Apprentis d'Auteuil",
+        "Apprentis d’Auteuil",
         None,
     )
     APTIC = (
@@ -567,7 +567,7 @@ class LabelNational(EnhancedEnum):
     )
     FEDERATION_DES_ENTREPRISES_DINSERTION = (
         "federation-des-entreprises-dinsertion",
-        "Fédération des entreprises d'insertion",
+        "Fédération des entreprises d’insertion",
         None,
     )
     FORCE_FEMMES = (
@@ -597,7 +597,7 @@ class LabelNational(EnhancedEnum):
     )
     GRANDES_ECOLES_DU_NUMERIQUE = (
         "grandes-ecoles-du-numerique",
-        "Grand Test Couveuse d'entreprise",
+        "Grand Test Couveuse d’entreprise",
         None,
     )
     GRAND_TEST_COUVEUSE_DENTREPRISE = (
@@ -607,7 +607,7 @@ class LabelNational(EnhancedEnum):
     )
     HUP = (
         "hup",
-        "H'UP",
+        "H’UP",
         None,
     )
     INAE = (
@@ -647,7 +647,7 @@ class LabelNational(EnhancedEnum):
     )
     MAISONS_DE_LEMPLOI = (
         "maisons-de-lemploi",
-        "Maisons de l'Emploi",
+        "Maisons de l’Emploi",
         None,
     )
     MDPH = (
@@ -757,7 +757,7 @@ class LabelNational(EnhancedEnum):
     )
     UNAF = (
         "unaf",
-        "Union nationale de l'aide aux familles",
+        "Union nationale de l’aide aux familles",
         None,
     )
     UNAI = (
@@ -767,7 +767,7 @@ class LabelNational(EnhancedEnum):
     )
     UNCCAS = (
         "unccas",
-        "Union nationale des centres communaux d'action sociale",
+        "Union nationale des centres communaux d’action sociale",
         None,
     )
     UNEA = (
@@ -783,6 +783,72 @@ class LabelNational(EnhancedEnum):
 
 
 class Thematique(EnhancedEnum):
+    ACCES_AUX_DROITS_ET_CITOYENNETE = (
+        "acces-aux-droits-et-citoyennete",
+        "Accès aux droits & citoyenneté",
+        None,
+    )
+    ACCES_AUX_DROITS_ET_CITOYENNETE__ACCOMPAGNEMENT_DEMARCHES_ADMINISTRATIVES = (
+        (
+            "acces-aux-droits-et-citoyennete"
+            "--accompagnement-dans-les-demarches-administratives"
+        ),
+        "Accompagnement dans les démarches administratives",
+        None,
+    )
+    ACCES_AUX_DROITS_ET_CITOYENNETE__ACCOMPAGNEMENT_JURIDIQUE = (
+        "acces-aux-droits-et-citoyennete--accompagnement-juridique",
+        "Accompagnement juridique",
+        None,
+    )
+    ACCES_AUX_DROITS_ET_CITOYENNETE__CONNAITRE_SES_DROITS = (
+        "acces-aux-droits-et-citoyennete--connaitre-ses-droits",
+        "Connaitre ses droits",
+        None,
+    )
+    ACCES_AUX_DROITS_ET_CITOYENNETE__DEMANDEURS_DASILE_ET_NATURALISATION = (
+        "acces-aux-droits-et-citoyennete--demandeurs-dasile-et-naturalisation",
+        "Demandeurs d’asile et naturalisation",
+        None,
+    )
+    ACCES_AUX_DROITS_ET_CITOYENNETE__FACILITER_LACTION_CITOYENNE = (
+        "acces-aux-droits-et-citoyennete--faciliter-laction-citoyenne",
+        "Faciliter l’action citoyenne",
+        None,
+    )
+    ACCES_AUX_DROITS_ET_CITOYENNETE__DEVELOPPEMENT_DURABLE = (
+        "acces-aux-droits-et-citoyennete--developpement-durable",
+        "Développement durable",
+        None,
+    )
+
+    ACCOMPAGNEMENT_SOCIO_PRO_PERSONNALISE = (
+        "accompagnement-social-et-professionnel-personnalise",
+        "Accompagnement social et professionnel personnalisé",
+        None,
+    )
+    ACCOMPAGNEMENT_SOCIO_PRO_PERSONNALISE__DECROCHAGE_SCOLAIRE = (
+        "accompagnement-social-et-professionnel-personnalise--decrochage-scolaire",
+        "Décrochage scolaire",
+        None,
+    )
+    ACCOMPAGNEMENT_SOCIO_PRO_PERSONNALISE__DEFINITION_DU_PROJET_PROFESSIONNEL = (
+        (
+            "accompagnement-social-et-professionnel-personnalise--"
+            "definition-du-projet-professionnel"
+        ),
+        "Définition du projet professionnel",
+        None,
+    )
+    ACCOMPAGNEMENT_SOCIO_PRO_PERSONNALISE__PARCOURS_D_INSERTION_SOCIOPROFESSIONNEL = (
+        (
+            "accompagnement-social-et-professionnel-personnalise--"
+            "parcours-d-insertion-socioprofessionnel"
+        ),
+        "Parcours d’insertion socio-professionnel",
+        None,
+    )
+
     CHOISIR_UN_METIER = (
         "choisir-un-metier",
         "Choisir un métier",
@@ -795,12 +861,12 @@ class Thematique(EnhancedEnum):
     )
     CHOISIR_UN_METIER__CONNAITRE_LES_OPPORTUNITES_DEMPLOI = (
         "choisir-un-metier--connaitre-les-opportunites-demploi",
-        "Connaître les opportunités d'emploi",
+        "Connaître les opportunités d’emploi",
         None,
     )
     CHOISIR_UN_METIER__DECOUVRIR_UN_METIER_OU_UN_SECTEUR_DACTIVITE = (
         "choisir-un-metier--decouvrir-un-metier-ou-un-secteur-dactivite",
-        "Découvrir un métier ou un secteur d'activité",
+        "Découvrir un métier ou un secteur d’activité",
         None,
     )
     CHOISIR_UN_METIER__CONFIRMER_SON_CHOIX_DE_METIER = (
@@ -811,27 +877,27 @@ class Thematique(EnhancedEnum):
 
     CREATION_ACTIVITE = (
         "creation-activite",
-        "Création d'activité",
+        "Création d’activité",
         None,
     )
-    CREATION_ACTIVITE__DE_L_IDEE_AU_PROJET = (
-        "creation-activite--de-l-idee-au-projet",
-        "De l'idée au projet",
+    CREATION_ACTIVITE__DEFINIR_SON_PROJET_DE_CREATION_DENTREPRISE = (
+        "creation-activite--definir-son-projet-de-creation-dentreprise",
+        "Définir son projet de création d’entreprise",
         None,
     )
-    CREATION_ACTIVITE__DEMARRER_SON_ACTIVITE = (
-        "creation-activite--demarrer-son-activite",
-        "Démarrer son activité",
+    CREATION_ACTIVITE__DEVELOPPER_SON_ENTREPRISE = (
+        "creation-activite--developper-son-entreprise",
+        "Développer son entreprise",
         None,
     )
-    CREATION_ACTIVITE__ELABORER_SON_PROJET = (
-        "creation-activite--elaborer-son-projet",
-        "Elaborer son projet",
+    CREATION_ACTIVITE__STRUCTURER_SON_PROJET_DE_CREATION_DENTREPRISE = (
+        "creation-activite--structurer-son-projet-de-creation-dentreprise",
+        "Structurer son projet de création d’entreprise",
         None,
     )
     CREATION_ACTIVITE__RESEAUTAGE_POUR_CREATEURS_DENTREPRISE = (
         "creation-activite--reseautage-pour-createurs-dentreprise",
-        "Réseautage pour créateurs d'entreprise",
+        "Réseautage pour créateurs d’entreprise",
         None,
     )
     CREATION_ACTIVITE__FINANCER_SON_PROJET = (
@@ -840,6 +906,214 @@ class Thematique(EnhancedEnum):
         None,
     )
 
+    EQUIPEMENT_ET_ALIMENTATION = (
+        "equipement-et-alimentation",
+        "Equipement et alimentation",
+        None,
+    )
+    EQUIPEMENT_ET_ALIMENTATION__ACCES_A_DU_MATERIEL_INFORMATIQUE = (
+        "equipement-et-alimentation--acces-a-du-materiel-informatique",
+        "Accès à du matériel informatique",
+        None,
+    )
+    EQUIPEMENT_ET_ALIMENTATION__ACCES_A_UN_TELEPHONE_ET_UN_ABONNEMENT = (
+        "equipement-et-alimentation--acces-a-un-telephone-et-un-abonnement",
+        "Accès à un téléphone et un abonnement",
+        None,
+    )
+    EQUIPEMENT_ET_ALIMENTATION__ALIMENTATION = (
+        "equipement-et-alimentation--alimentation",
+        "Alimentation",
+        None,
+    )
+    EQUIPEMENT_ET_ALIMENTATION__ELECTROMENAGER = (
+        "equipement-et-alimentation--electromenager",
+        "Electroménager",
+        None,
+    )
+    EQUIPEMENT_ET_ALIMENTATION__HABILLEMENT = (
+        "equipement-et-alimentation--habillement",
+        "Habillement",
+        None,
+    )
+
+    FAMILLE = (
+        "famille",
+        "Famille",
+        None,
+    )
+    FAMILLE__INFORMATION_ET_ACCOMPAGNEMENT_DES_PARENTS = (
+        "famille--information-et-accompagnement-des-parents",
+        "Information et accompagnement des parents",
+        None,
+    )
+    FAMILLE__GARDE_DENFANTS = (
+        "famille--garde-denfants",
+        "Garde d’enfants",
+        None,
+    )
+    FAMILLE__JEUNES_SANS_SOUTIEN_FAMILIAL = (
+        "famille--jeunes-sans-soutien-familial",
+        "Jeunes sans soutien familial",
+        None,
+    )
+    FAMILLE__SOUTIEN_AUX_FAMILLES = (
+        "famille--soutien-aux-familles",
+        "Soutien aux familles",
+        None,
+    )
+    FAMILLE__VIOLENCES_INTRAFAMILIALES = (
+        "famille--violences-intrafamiliales",
+        "Violences intrafamiliales",
+        None,
+    )
+    FAMILLE__ACCOMPAGNEMENT_FEMME_ENCEINTE_BEBE_JEUNE_ENFANT = (
+        "famille--accompagnement-femme-enceinte-bebe-jeune-enfant",
+        "Accompagnement femme enceinte, bébé, jeune enfant",
+        None,
+    )
+    FAMILLE__SOUTIEN_A_LA_PARENTALITE = (
+        "famille--soutien-a-la-parentalite",
+        "Soutien à la parentalité",
+        None,
+    )
+
+    GESTION_FINANCIERE = (
+        "gestion-financiere",
+        "Gestion financière",
+        None,
+    )
+    GESTION_FINANCIERE__ACCOMPAGNEMENT_AUX_PERSONNES_EN_DIFFICULTES_FINANCIERES = (
+        "gestion-financiere--accompagnement-aux-personnes-en-difficultes-financieres",
+        "Accompagnement aux personnes en difficultés financières",
+        None,
+    )
+    GESTION_FINANCIERE__APPRENDRE_A_GERER_SON_BUDGET = (
+        "gestion-financiere--apprendre-a-gerer-son-budget",
+        "Apprendre à gérer son budget",
+        None,
+    )
+    GESTION_FINANCIERE__PREVENTION_ET_GESTION_DU_SURENDETTEMENT = (
+        "gestion-financiere--prevention-et-gestion-du-surendettement",
+        "Prévention et gestion du surendettement",
+        None,
+    )
+    GESTION_FINANCIERE__CREATION_ET_UTILISATION_DUN_COMPTE_BANCAIRE = (
+        "gestion-financiere--creation-et-utilisation-dun-compte-bancaire",
+        "Création et utilisation d’un compte bancaire",
+        None,
+    )
+    GESTION_FINANCIERE__ACCES_AU_MICRO_CREDIT = (
+        "gestion-financiere--acces-au-micro-credit",
+        "Accès au micro-crédit",
+        None,
+    )
+    GESTION_FINANCIERE__OBTENIR_UNE_AIDE_ALIMENTAIRE = (
+        "gestion-financiere--obtenir-une-aide-alimentaire",
+        "Obtenir une aide alimentaire",
+        None,
+    )
+    GESTION_FINANCIERE__BENEFICIER_DAIDES_FINANCIERES = (
+        "gestion-financiere--beneficier-daides-financieres",
+        "Bénéficier d’aides financières",
+        None,
+    )
+
+    HANDICAP = (
+        "handicap",
+        "Handicap",
+        None,
+    )
+    HANDICAP__ACCOMPAGNEMENT_PAR_UNE_STRUCTURE_SPECIALISEE = (
+        "handicap--accompagnement-par-une-structure-specialisee",
+        "Accompagnement par une structure spécialisée",
+        None,
+    )
+    HANDICAP__ADAPTATION_AU_POSTE_DE_TRAVAIL = (
+        "handicap--adaptation-au-poste-de-travail",
+        "Adaptation au poste de travail",
+        None,
+    )
+    HANDICAP__ADAPTER_SON_LOGEMENT = (
+        "handicap--adapter-son-logement",
+        "Adapter son logement",
+        None,
+    )
+    HANDICAP__CONNAISSANCE_DES_DROITS_DES_TRAVAILLEURS = (
+        "handicap--connaissance-des-droits-des-travailleurs",
+        "Connaissance des droits des travailleurs",
+        None,
+    )
+    HANDICAP__FAIRE_RECONNAITRE_UN_HANDICAP = (
+        "handicap--faire-reconnaitre-un-handicap",
+        "Faire reconnaitre un handicap",
+        None,
+    )
+    HANDICAP__FAVORISER_LE_RETOUR_ET_LE_MAINTIEN_DANS_LEMPLOI = (
+        "handicap--favoriser-le-retour-et-le-maintien-dans-lemploi",
+        "Favoriser le retour et le maintien dans l’emploi",
+        None,
+    )
+    HANDICAP__MOBILITE_DES_PERSONNES_EN_SITUATION_DE_HANDICAP = (
+        "handicap--mobilite-des-personnes-en-situation-de-handicap",
+        "Mobilité des personnes en situation de handicap",
+        None,
+    )
+    HANDICAP__GERER_LE_DEPART_A_LA_RETRAITE_DES_PERSONNES_EN_SITUATION_DE_HANDICAP = (
+        (
+            "handicap--"
+            "gerer-le-depart-a-la-retraite-des-personnes-en-situation-de-handicap"
+        ),
+        "Gérer le départ à la retraite des personnes en situation de handicap",
+        None,
+    )
+
+    LOGEMENT_HEBERGEMENT = (
+        "logement-hebergement",
+        "Logement et hébergement",
+        None,
+    )
+    LOGEMENT_HEBERGEMENT__ETRE_ACCOMPAGNE_POUR_SE_LOGER = (
+        "logement-hebergement--etre-accompagne-pour-se-loger",
+        "Etre accompagné(e) pour se loger",
+        None,
+    )
+    LOGEMENT_HEBERGEMENT__BESOIN_DADAPTER_MON_LOGEMENT = (
+        "logement-hebergement--besoin-dadapter-mon-logement",
+        "Besoin d’adapter mon logement",
+        None,
+    )
+    LOGEMENT_HEBERGEMENT__DEMENAGEMENT = (
+        "logement-hebergement--demenagement",
+        "Déménagement",
+        None,
+    )
+    LOGEMENT_HEBERGEMENT__MAL_LOGES_SANS_LOGIS = (
+        "logement-hebergement--mal-loges-sans-logis",
+        "Mal logé/sans logis",
+        None,
+    )
+    LOGEMENT_HEBERGEMENT__PROBLEME_AVEC_SON_LOGEMENT = (
+        "logement-hebergement--probleme-avec-son-logement",
+        "Problème avec son logement",
+        None,
+    )
+    LOGEMENT_HEBERGEMENT__REPRENDRE_UN_EMPLOI_OU_UNE_FORMATION = (
+        "logement-hebergement--reprendre-un-emploi-ou-une-formation",
+        "Reprendre un emploi ou une formation",
+        None,
+    )
+    LOGEMENT_HEBERGEMENT__CONNAISSANCE_DE_SES_DROITS_ET_INTERLOCUTEURS = (
+        "logement-hebergement--connaissance-de-ses-droits-et-interlocuteurs",
+        "Connaissance de ses droits et interlocuteurs",
+        None,
+    )
+    LOGEMENT_HEBERGEMENT__GERER_SON_BUDGET = (
+        "logement-hebergement--gerer-son-budget",
+        "Gérer son budget",
+        None,
+    )
+
     MOBILITE = (
         "mobilite",
         "Mobilité",
@@ -872,7 +1146,7 @@ class Thematique(EnhancedEnum):
     )
     MOBILITE__AIDES_A_LA_REPRISE_DEMPLOI_OU_A_LA_FORMATION = (
         "mobilite--aides-a-la-reprise-demploi-ou-a-la-formation",
-        "Aides à la reprise d'emploi ou à la formation",
+        "Aides à la reprise d’emploi ou à la formation",
         None,
     )
     MOBILITE__COMPRENDRE_ET_UTILISER_LES_TRANSPORTS_EN_COMMUN = (
@@ -948,7 +1222,7 @@ class Thematique(EnhancedEnum):
     )
     NUMERIQUE__S_EQUIPER_EN_MATERIEL_INFORMATIQUE = (
         "numerique--s-equiper-en-materiel-informatique",
-        "S'équiper en matériel informatique",
+        "S’équiper en matériel informatique",
         None,
     )
     NUMERIQUE__CREER_ET_DEVELOPPER_MON_ENTREPRISE = (
@@ -973,7 +1247,7 @@ class Thematique(EnhancedEnum):
     )
     NUMERIQUE__SOUTENIR_LA_PARENTALITE_ET_L_EDUCATION_AVEC_LE_NUMERIQUE = (
         "numerique--soutenir-la-parentalite-et-l-education-avec-le-numerique",
-        "Soutenir la parentalité et l'éducation avec le numérique",
+        "Soutenir la parentalité et l’éducation avec le numérique",
         None,
     )
 
@@ -999,7 +1273,154 @@ class Thematique(EnhancedEnum):
     )
     PREPARER_SA_CANDIDATURE__ORGANISER_SES_DEMARCHES_DE_RECHERCHE_DEMPLOI = (
         "preparer-sa-candidature--organiser-ses-demarches-de-recherche-demploi",
-        "Organiser ses démarches de recherche d'emploi",
+        "Organiser ses démarches de recherche d’emploi",
+        None,
+    )
+
+    REMOBILISATION = (
+        "remobilisation",
+        "Remobilisation",
+        None,
+    )
+    REMOBILISATION__BIEN_ETRE = (
+        "remobilisation--bien-etre",
+        "Bien être",
+        None,
+    )
+    REMOBILISATION__IDENTIFIER_SES_COMPETENCES_ET_APTITUDES = (
+        "remobilisation--identifier-ses-competences-et-aptitudes",
+        "Identifier ses compétences et aptitudes",
+        None,
+    )
+    REMOBILISATION__LIEN_SOCIAL = (
+        "remobilisation--lien-social",
+        "Lien social",
+        None,
+    )
+    REMOBILISATION__RESTAURER_SA_CONFIANCE_SON_IMAGE_DE_SOI = (
+        "remobilisation--restaurer-sa-confiance-son-image-de-soi",
+        "Restaurer sa confiance, son image de soi",
+        None,
+    )
+    REMOBILISATION__PRESSION_SOCIALE = (
+        "remobilisation--pression-sociale",
+        "Pression sociale",
+        None,
+    )
+    REMOBILISATION__DISCRIMINATION = (
+        "remobilisation--discrimination",
+        "Discrimination",
+        None,
+    )
+    REMOBILISATION__DECOUVRIR_SON_POTENTIEL_VIA_LE_SPORT_ET_LA_CULTURE = (
+        "remobilisation--decouvrir-son-potentiel-via-le-sport-et-la-culture",
+        "Découvrir son potentiel via le sport et la culture",
+        None,
+    )
+    REMOBILISATION__PARTICIPER_A_DES_ACTIONS_SOLIDAIRES_OU_DE_BÉNÉVOLAT = (
+        "remobilisation--participer-a-des-actions-solidaires-ou-de-benevolat",
+        "Participer à des actions solidaires ou de bénévolat",
+        None,
+    )
+
+    SANTE = (
+        "sante",
+        "Santé",
+        None,
+    )
+    SANTE__FAIRE_FACE_A_UNE_SITUATION_DADDICTION = (
+        "sante--faire-face-a-une-situation-daddiction",
+        "Faire face à une situation d’addiction",
+        None,
+    )
+    SANTE__BIEN_ETRE_PSYCHOLOGIQUE = (
+        "sante--bien-etre-psychologique",
+        "Bien être psychologique",
+        None,
+    )
+    SANTE__OBTENIR_LA_PRISE_EN_CHARGE_DE_FRAIS_MEDICAUX = (
+        "sante--obtenir-la-prise-en-charge-de-frais-medicaux",
+        "Obtenir la prise en charge de frais médicaux",
+        None,
+    )
+    SANTE__SE_SOIGNER_ET_PRÉVENIR_LA_MALADIE = (
+        "sante--se-soigner-et-prevenir-la-maladie",
+        "Se soigner et prévenir la maladie",
+        None,
+    )
+    SANTE__ACCOMPAGNEMENT_DE_LA_FEMME_ENCEINTE_DU_BEBE_ET_DU_JEUNE_ENFANT = (
+        "sante--accompagnement-de-la-femme-enceinte-du-bebe-et-du-jeune-enfant",
+        "Accompagnement de la femme enceinte, du bébé et du jeune enfant",
+        None,
+    )
+    SANTE__PREVENTION_ET_ACCES_AUX_SOINS = (
+        "sante--prevention-et-acces-aux-soins",
+        (
+            "Prévention et accès aux soins "
+            "(vaccination, éducation à la santé, lutte contre la tuberculose…)."
+        ),
+        None,
+    )
+    SANTE__VIE_RELATIONNELLE_ET_AFFECTIVE = (
+        "sante--vie-relationnelle-et-affective",
+        "Vie relationnelle et affective, dépistage et prévention des IST/VIH…",
+        None,
+    )
+    SANTE__ACCOMPAGNER_LES_TRAUMATISMES = (
+        "sante--accompagner-les-traumatismes",
+        "Accompagner les traumatismes",
+        None,
+    )
+    SANTE__ACCES_AUX_SOINS = (
+        "sante--acces-aux-soins",
+        "Accès aux soins",
+        None,
+    )
+    SANTE__DIAGNOSTIC_ET_ACCOMPAGNEMENT_A_LEMPLOYABILITE = (
+        "sante--diagnostic-et-accompagnement-a-lemployabilite",
+        "Diagnostic et accompagnement à l’employabailité",
+        None,
+    )
+
+    SE_FORMER = (
+        "se-former",
+        "Se former",
+        None,
+    )
+    SE_FORMER__TROUVER_SA_FORMATION = (
+        "se-former--trouver-sa-formation",
+        "Trouver sa formation",
+        None,
+    )
+    SE_FORMER__MONTER_SON_DOSSIER_DE_FORMATION = (
+        "se-former--monter-son-dossier-de-formation",
+        "Monter son dossier de formation",
+        None,
+    )
+    SE_FORMER__UTILISER_LE_NUMÉRIQUE = (
+        "se-former--utiliser-le-numerique",
+        "Utiliser le numérique",
+        None,
+    )
+
+    SOUVRIR_A_L_INTERNATIONAL = (
+        "souvrir-a-linternational",
+        "S’ouvrir à l’international",
+        None,
+    )
+    SOUVRIR_A_L_INTERNATIONAL__CONNAITRE_LES_OPPORTUNITES_DEMPLOI_A_LETRANGER = (
+        "souvrir-a-linternational--connaitre-les-opportunites-demploi-a-letranger",
+        "Connaître les opportunités d’emploi à l’étranger",
+        None,
+    )
+    SOUVRIR_A_L_INTERNATIONAL__SINFORMER_SUR_LES_AIDES_POUR_TRAVAILLER_A_LETRANGER = (
+        "souvrir-a-linternational--sinformer-sur-les-aides-pour-travailler-a-letranger",
+        "S’informer sur les aides pour travailler à l’étranger",
+        None,
+    )
+    SOUVRIR_A_L_INTERNATIONAL__SORGANISER_SUITE_A_SON_RETOUR_EN_FRANCE = (
+        "souvrir-a-linternational--sorganiser-suite-a-son-retour-en-france",
+        "S’organiser suite à son retour en France",
         None,
     )
 
@@ -1010,7 +1431,7 @@ class Thematique(EnhancedEnum):
     )
     TROUVER_UN_EMPLOI__REPONDRE_A_DES_OFFRES_DEMPLOI = (
         "trouver-un-emploi--repondre-a-des-offres-demploi",
-        "Répondre à des offres d'emploi",
+        "Répondre à des offres d’emploi",
         None,
     )
     TROUVER_UN_EMPLOI__FAIRE_DES_CANDIDATURES_SPONTANEES = (
@@ -1034,13 +1455,13 @@ class TypologieService(EnhancedEnum):
     ACCOMPAGNEMENT = (
         "accompagnement",
         "Accompagnement",
-        "Etre accompagné·e dans ses démarches ou son retour à l'emploi durable",
+        "Etre accompagné·e dans ses démarches ou son retour à l’emploi durable",
     )
     ACCUEIL = (
         "accueil",
         "Accueil",
         """
-            Lieux d'écoute et d'évaluation des besoins de la personne qui se présente
+            Lieux d’écoute et d’évaluation des besoins de la personne qui se présente
             afin de la guider vers le ou les organismes les plus susceptibles de
             répondre à ses besoins
         """,
@@ -1071,7 +1492,7 @@ class TypologieService(EnhancedEnum):
     INFORMATION = (
         "information",
         "Information",
-        "Premier niveau d'information apporté par des professionnels du secteur",
+        "Premier niveau d’information apporté par des professionnels du secteur",
     )
     NUMÉRIQUE = (
         "numerique",
@@ -1091,7 +1512,7 @@ class TypologieService(EnhancedEnum):
     FINANCEMENT = (
         "financement",
         "Financement ",
-        "Crédit solidaire, prêts à taux zéro pour le financement d'un projet",
+        "Crédit solidaire, prêts à taux zéro pour le financement d’un projet",
     )
 
 
@@ -1112,17 +1533,17 @@ class Frais(EnhancedEnum):
     PAYANT = (
         "payant",
         "Payant",
-        "L'accès au lieu et/ou à ses services est payant",
+        "L’accès au lieu et/ou à ses services est payant",
     )
     ADHESION = (
         "adhesion",
         "Adhésion",
-        "L'accès au lieu et/ou à ses services nécessite d'y adhérer",
+        "L’accès au lieu et/ou à ses services nécessite d’y adhérer",
     )
     PASS_NUMERIQUE = (
         "pass-numerique",
         "Accepte le pass numérique",
-        "Il est possible d'utiliser un Pass numérique pour accéder au lieu",
+        "Il est possible d’utiliser un Pass numérique pour accéder au lieu",
     )
 
 
@@ -1172,7 +1593,7 @@ class Profil(EnhancedEnum):
     )
     HANDICAPS_MENTAUX = (
         "handicaps-mentaux",
-        "Handicaps mentaux : déficiences limitant les activités d'une personne",
+        "Handicaps mentaux : déficiences limitant les activités d’une personne",
         None,
     )
     FEMMES = (
@@ -1182,7 +1603,7 @@ class Profil(EnhancedEnum):
     )
     PERSONNES_EN_SITUATION_ILLETTRISME = (
         "personnes-en-situation-illettrisme",
-        "Personnes en situation d'illettrisme",
+        "Personnes en situation d’illettrisme",
         None,
     )
 
